@@ -1,8 +1,8 @@
-# $Id: Define.pm 47203 2007-11-08 15:03:51Z wsnyder $
+# $Id: Define.pm 49231 2008-01-03 16:53:43Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 2001-2007 by Wilson Snyder.  This program is free software;
+# Copyright 2001-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 #
@@ -21,7 +21,7 @@ use Verilog::Language;	# For value parsing
 use strict;
 use vars qw ($VERSION);
 use base qw (SystemC::Vregs::Subclass);
-$VERSION = '1.441';
+$VERSION = '1.450';
 
 #Fields:
 #	{name}			Field name (Subclass)
@@ -120,7 +120,7 @@ sub clean_rst {
     $self->{class}{bits} = $bits;
 
     if ($bits && $bits<32 && hex($self->{rst_val}||"0")>= (1<<$bits)) {
-	$self->warn ("Define value wider then width: ".$self->{rst}." > width "
+	$self->warn ("Define value wider than width: ".$self->{rst}." > width "
 		     .$self->{class}{bits}."\n");
     }
 }
@@ -197,7 +197,7 @@ via the self hash: $self->{field}.
 =item bits
 
 Number of bits in the define.  If not specified, it is assumed to be a
-unsized object that is less then 32 bits.
+unsized object that is less than 32 bits.
 
 =item desc
 
@@ -257,7 +257,7 @@ Vregs is part of the L<http://www.veripool.com/> free Verilog software tool
 suite.  The latest version is available from CPAN and from
 L<http://www.veripool.com/vregs.html>.  /www.veripool.com/>.
 
-Copyright 2001-2007 by Wilson Snyder.  This package is free software; you
+Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
